from genlab_ai_game_util import RedisClient

if __name__ == '__main__':
    k = '__python_test__'
    v = 'value'
    mapping = dict(key1="value1", key2="value2")
    redisClient = RedisClient(host='43.138.239.86', port=7000, password='B8J0fg5589HG9g56', socket_timeout=3,
                              socket_connect_timeout=3)
    # print(redisClient.set_kv(k, v, 10))
    # print(redisClient.get_kv(k))
    print(redisClient.set_hash(k, mapping))
    print(redisClient.get_hash_all(k))
    print(redisClient.exists(k))
    print(redisClient.get_hash_by_key(k, 'key1'))
    print(redisClient.del_hash_by_key(k, 'key2'))
    print(redisClient.inc("__python_test__inc__"))
    print(redisClient.get_kv("__python_test__inc__"))
    redisClient.disconnect()


import json
import sys

class BaseCommand:

    def __init__(self):
        self.inputFile = sys.argv[1]
        self.outputFile = sys.argv[2]

    def command(self, input_json):
        return ''

    def run(self):
        with open(self.inputFile, 'r', encoding='utf-8') as file:
            data = file.read()
        # 入口参数
        input_json = json.loads(data)
        output_json = self.run(input_json)
        with open(self.outputFile, 'w', encoding='utf-8') as file:
            json.dump(output_json, file, indent=4)



from setuptools import setup, find_packages

setup(
    name='genlab_ai_game_util',  # 包名
    version='0.0.2',  # 包的版本
    packages=find_packages(),  # 自动寻找包
    install_requires=[  # 列出依赖包
        'redis>=5.1.1',
    ],
    author='hy',  # 作者信息
    author_email='huyang3572@gmail.com',  # 作者邮箱
    description='ai game python',  # 简短描述
    long_description=open('README.md').read(),  # 长描述，通常来自README.md
    long_description_content_type='text/markdown',
    url='',  # 项目主页
    classifiers=[  # 分类器用于包的元数据
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.9',  # Python版本要求
)


import atexit
import redis

class RedisClient:
    # 单例
    _instance = None

    def __new__(cls, *args, **kwargs):
        if cls._instance is None:
            cls._instance = super(RedisClient, cls).__new__(cls)
        return cls._instance

    def __init__(self, host, port, password, socket_timeout=3, socket_connect_timeout=3):
        self.redis_client = None
        # 注册退出钩子
        atexit.register(self.graceful_exit)
        try:
            self.connect(host, port, password, socket_timeout, socket_connect_timeout)
        except Exception as e:
            print(f'redis connect failed.{e}')

    def graceful_exit(self):
        print("start Closing Redis connection...")
        self.disconnect()
        print("finish Closing Redis connection...")

    def connect(self, host, port, password, socket_timeout, socket_connect_timeout):
        if self.redis_client is None:
            self.redis_client = redis.Redis(
                host=host,
                port=port,
                password=password,
                socket_timeout=socket_timeout,
                socket_connect_timeout=socket_connect_timeout)
            pong = self.redis_client.ping()
            print(f"redis connect ok:{pong}")

    def disconnect(self):
        try:
            if self.redis_client is not None:
                self.redis_client.close()
                self.redis_client = None
                print("redis disconnect")
        except Exception as e:
            print(f"redis disconnect:{e}")

    # redis中是否存在某个key
    def exists(self, key):
        try:
            return True, self.redis_client.exists(key)
        except Exception as e:
            print(f"exists:{e}")
            return False, e

    # redis让某个key自增
    def inc(self, key):
        try:
            return True, self.redis_client.incr(key)
        except Exception as e:
            print(f"inc:{e}")
            return False, e

    # 写入kv
    def set_kv(self, key, value, expire_second=0):
        try:
            if expire_second == 0:
                return True, self.redis_client.set(key, value)
            return True, self.redis_client.set(key, value, ex=expire_second)
        except Exception as e:
            print(f"set_kv:{e}")
            return False, e

    # 读取kv
    def get_kv(self, key):
        try:
            value = self.redis_client.get(key)
            # 如果返回的是字节类型，转换为字符串
            if value:
                return True, value.decode('utf-8')  # 使用utf-8解码
            else:
                return True, None
        except Exception as e:
            print(f"get_kv:{e}")
            return False, e

    # 删除某个key
    def del_key(self, key):
        try:
            return True, self.redis_client.delete(key)
        except Exception as e:
            print(f"del_key:{e}")
            return False, e

    # 写入hash
    def set_hash(self, name, hash):
        try:
            return True, self.redis_client.hset(name, mapping=hash)
        except Exception as e:
            print(f"set_hash:{e}")
            return False, e

    # 读取全部hash
    def get_hash_all(self, name):
        try:
            hash_data = self.redis_client.hgetall(name)
            if hash_data is None:
                return True, None
            else:
                return True, {key.decode('utf-8'): value.decode('utf-8') for key, value in hash_data.items()}
        except Exception as e:
            print(f"get_hash_all:{e}")
            return False, e

    # 读取hash某个key
    def get_hash_by_key(self, name, key):
        try:
            hash_data = self.redis_client.hget(name, key)
            if hash_data is None:
                return True, None
            else:
                return True, hash_data.decode('utf-8')
        except Exception as e:
            print(f"get_hash_by_key:{e}")
            return False, e

    # 删除hash某个key
    def del_hash_by_key(self, name, key):
        try:
            return True, self.redis_client.hdel(name, key)
        except Exception as e:
            print(f"del_hash_by_key:{e}")
            return False, e
